@@ -37,7 +37,7 @@ class VirtualMachineSnapshot(NamespacedResource):
         )
         self.vm_name = vm_name
 
-    def to_dict(self):
+    def to_dict(self) -> None:
         super().to_dict()
         if not self.yaml_file:
             spec = self.res.setdefault("spec", {})
